@@ -8,7 +8,7 @@
 #
 package Dist::Zilla::Role::Git::Repo;
 {
-  $Dist::Zilla::Role::Git::Repo::VERSION = '1.120370';
+  $Dist::Zilla::Role::Git::Repo::VERSION = '2.019';
 }
 
 # ABSTRACT: Provide repository information for Git plugins
@@ -18,10 +18,20 @@ use Moose::Role;
 has 'repo_root'   => ( is => 'ro', isa => 'Str', default => '.' );
 
 
+my %cached_wrapper;
+
+sub git {
+  my $root = shift->repo_root;
+
+  $cached_wrapper{$root} ||= do {
+    require Git::Wrapper;
+    Git::Wrapper->new( $root );
+  };
+}
+
 1;
 
-
-
+__END__
 
 =pod
 
@@ -31,11 +41,12 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 1.120370
+version 2.019
 
 =head1 DESCRIPTION
 
-This role is used within the git plugin to get information about the repository structure.
+This role is used within the Git plugins to get information about the
+repository structure, and to create a Git::Wrapper object.
 
 =head1 ATTRIBUTES
 
@@ -43,6 +54,17 @@ This role is used within the git plugin to get information about the repository
 
 The repository root, either as a full path or relative to the distribution root. Default is C<.>.
 
+=head1 METHODS
+
+=head2 git
+
+  $git = $plugin->git;
+
+This method returns a Git::Wrapper object for the C<repo_root>
+directory, constructing one if necessary.  The object is shared
+between all plugins that consume this role (if they have the same
+C<repo_root>).
+
 =head1 AUTHOR
 
 Jerome Quelin
@@ -55,7 +77,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
